@@ -119,7 +119,7 @@ class DevEntries(Command):
             LOG.debug("", exc_info=exc)
             sys.exit(f"{last_ref} is not a valid commit reference")
 
-        self.glog_entries: list[GitLogEntry] = []
+        self.last_entry: GitLogEntry | None = None
 
     @classmethod
     def make_parser(
@@ -180,14 +180,15 @@ class DevEntries(Command):
                 self.last_entry.add_to_clog(changelog)
 
     def create_archive(self, nv: str):
-        with tarfile.open(self.outdir / f"{nv}.tar.gz", "w") as tf:
+        with tarfile.open(self.outdir / f"{nv}.tar.gz", "w:gz") as tf:
             self.repository.write_archive(
                 self.repository.head.target, tf, prefix=f"{nv}/"
             )
 
     def run(self) -> None:
         self.add_entries()
-        self.spec.set_version_and_release(self.last_entry.version, "1")
+        if self.last_entry:
+            self.spec.set_version_and_release(self.last_entry.version, "1")
         nv = f"{self.spec.expanded_name}-{self.spec.expanded_version}"
         self.write_spec()
         if self.archive:
@@ -223,7 +224,7 @@ class DevSRPM(DevEntries):
             "_topdir": self.outdir,
             "_sourcedir": self.outdir,
             "_specdir": self.outdir,
-            "_srpmdir": self.srpm_outdir,
+            "_srcrpmdir ": self.srpm_outdir,
         }
         cmd: list[StrOrBytesPath] = [
             "rpmbuild",
